*+--------------------------------------------------------------------
*+
*+ Source Module => d:\ALASKA\WMI32BIT\\RUNW32.PRG
*+
*+    Copyright(C) 1983-2021 by Auge & Ohr
*+
*+    Functions: Procedure Main()
*+               Function HMG_Info()
*+               Function ProcessorInfo()
*+               Function BaseBoardInfo()
*+               Function BIOSInfo()
*+               Function PhysicalMemoryInfo()
*+               Function OS_Info()
*+               Static Function WMIService()
*+               Function TRIM_NUMBER()
*+               Function GetFormFaktorText()
*+               Function GetRAMtype()
*+
*+    Reformatted by Click! 2.05.37 on May-25-2021 at 12:01 pm
*+
*+--------------------------------------------------------------------

#IFDEF __XPP__
   #INCLUDE "dll.CH"
   #PRAGMA LIBRARY("ASCOM10.LIB")
   #define CRLF    CHR(13)+CHR(10)
#ELSE
   #include "HMG.ch"
   #include "hbgtinfo.ch"
   REQUEST HB_GT_WIN_DEFAULT                                             // Console
#ENDIF

*+--------------------------------------------------------------------
*+
*+    Procedure Main()
*+
*+--------------------------------------------------------------------
*+
PROCEDURE Main

LOCAL a, b, c, d, e, x

   a := HMG_Info()
   b := BaseBoardInfo()
   c := BIOSInfo()
   d := PhysicalMemoryInfo()
   e := ProcessorInfo()

   MEMOWRIT( "Info.TXT", a + b + c + d + e )
#IFDEF __XPP__
   RUNShell( "Info.TXT", "NOTEPAD.EXE", .T. )
#ELSE
   _Execute( GetActiveWindow(),, "Info.TXT",,, 5 )
#ENDIF

RETURN

*+--------------------------------------------------------------------
*+
*+    Function HMG_Info()
*+
*+    Called from ( runw32.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION HMG_Info()

LOCAL oWmi, oMemo
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine
LOCAL cInfo := REPLICATE( "-", 80 ) + CRLF

#IFDEF __XPP__
   ? cInfo += VERSION() + VERSION( 3 ) + CRLF + CRLF
   ? cInfo += OS_Info()
   ? cInfo += SUBSTR( "Available RAM" + SPACE( 30 ), 1, 30 ) + ":" + LTRIM( TRANSFORM( MEMORY( 0 ) / 1000, "999999" ) ) + " MB" + CRLF

   oWmi := WmiService()

   AADD( aProp, "Total Memory   " )

   colItems := oWMI:ExecQuery( "select * from Win32_ComputerSystem",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   LTRIM( TRANSFORM( VAL( oService:getProperty( "TotalPhysicalMemory" ) ) / 1000000, "999999" ) ) + " MB" } ) }

   ComEvalCollection( colItems, bCollBlock )

   jMax := LEN( aItem )
   iMax := LEN( aItem[ 1 ] )

   FOR j := 1 TO jMax
      FOR i := 1 TO iMax - 1
         IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
         ELSE
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
         ENDIF
         cInfo += cLine
      NEXT
   NEXT

#ELSE
   ? cInfo += HmgVersion()
   ? cInfo += HB_Compiler() + CRLF + CRLF
   ? cInfo += OS_Info()
   ? cInfo += IF( HMG_Is64Bits(), " 64 Bit", " 32 Bit" ) + CRLF
   ? cInfo += "Available RAM   : " + LTRIM( TRANSFORM( MEMORY( 0 ) / 1000, "999999" ) ) + " MB" + CRLF

   oWmi := WmiService()
   FOR EACH oMemo IN oWmi:ExecQuery( "SELECT * FROM Win32_ComputerSystem" )
      ? cInfo += "Total Memory    : " + LTRIM( TRANSFORM( VAL( oMemo:TotalPhysicalMemory ) / 1000000, "999999" ) ) + " MB" + CRLF
   NEXT
   ? cInfo += "" + CRLF

#ENDIF

RETURN cInfo

*+--------------------------------------------------------------------
*+
*+    Function ProcessorInfo()
*+
*+    Called from ( runw32.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION ProcessorInfo()

LOCAL oWmi, oCPU
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine
LOCAL cInfo := REPLICATE( "-", 80 ) + CRLF

   oWmi := WmiService()

#IFDEF __XPP__

   AADD( aProp, "Manufacturer   " )
   AADD( aProp, "Description    " )
   AADD( aProp, "Model          " )
   AADD( aProp, "Cores          " )
   AADD( aProp, "Logical        " )
   AADD( aProp, "Hyper-Threading" )
   AADD( aProp, "Current Speed  " )
   AADD( aProp, "Max Speed      " )
   AADD( aProp, "Ext Clock      " )

   colItems := oWMI:ExecQuery( "select * from Win32_Processor",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   oService:getProperty( "Manufacturer" ), ;
                   oService:getProperty( "Description" ), ;
                   oService:getProperty( "Name" ), ;
                   oService:getProperty( "NumberOfCores" ), ;
                   oService:getProperty( "NumberOfLogicalProcessors" ), ;
                   oService:getProperty( "CurrentClockSpeed" ), ;
                   oService:getProperty( "MaxClockSpeed" ), ;
                   oService:getProperty( "ExtClock" ) } ) }

   ComEvalCollection( colItems, bCollBlock )

   jMax := LEN( aItem )
   iMax := LEN( aItem[ 1 ] )

   FOR j := 1 TO jMax
      FOR i := 1 TO iMax - 1
         IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
         ELSE
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
         ENDIF
         cInfo += cLine
      NEXT
   NEXT

#ELSE

   ? cInfo += "ProcessorInfo     " + CRLF
   FOR EACH oCPU IN oWmi:ExecQuery( "SELECT * FROM Win32_Processor" )
      ? cInfo += "Manufacturer    : " + oCPU:Manufacturer + CRLF
      ? cInfo += "Description     : " + oCPU:Description + CRLF
      ? cInfo += "Model           : " + oCPU:Name + CRLF

      ? cInfo += "Cores           : " + TRIM_NUMBER( oCPU:NumberOfCores ) + CRLF
      ? cInfo += "Logical         : " + TRIM_NUMBER( oCPU:NumberOfLogicalProcessors ) + CRLF
      IF "Intel" $ oCPU:Manufacturer
         ? cInfo += "Hyper-Threading : " + IIF( oCPU:NumberOfCores < oCPU:NumberOfLogicalProcessors, "Enabled", "Disabled" ) + CRLF
      ENDIF
      ? cInfo += CRLF

      ? cInfo += "Current Speed   : " + TRIM_NUMBER( oCPU:CurrentClockSpeed ) + " MHz" + CRLF
      ? cInfo += "Max Speed       : " + TRIM_NUMBER( oCPU:MaxClockSpeed ) + " MHz" + CRLF
      ? cInfo += "Ext Clock       : " + TRIM_NUMBER( oCPU:ExtClock ) + " MHz" + CRLF
      ? cInfo += "" + CRLF

   NEXT

#ENDIF

RETURN cInfo

*+--------------------------------------------------------------------
*+
*+    Function BaseBoardInfo()
*+
*+    Called from ( runw32.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION BaseBoardInfo()

LOCAL oWmi, oBoard
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine
LOCAL cInfo := REPLICATE( "-", 80 ) + CRLF

   oWmi := WmiService()

#IFDEF __XPP__
   AADD( aProp, "Manufacturer   " )
   AADD( aProp, "Product        " )

   colItems := oWMI:ExecQuery( "select * from Win32_BaseBoard",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   oService:getProperty( "Manufacturer" ), ;
                   oService:getProperty( "Product" ) } ) }

   ComEvalCollection( colItems, bCollBlock )

   jMax := LEN( aItem )
   iMax := LEN( aItem[ 1 ] )

   FOR j := 1 TO jMax
      FOR i := 1 TO iMax - 1
         IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
         ELSE
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
         ENDIF
         cInfo += cLine
      NEXT
   NEXT

#ELSE
   ? cInfo += "BoardInfo       " + CRLF
   FOR EACH oBoard IN oWmi:ExecQuery( "SELECT * FROM Win32_BaseBoard" )
      ? cInfo += "Manufacturer    : " + oBoard:Manufacturer + CRLF
      ? cInfo += "Product         : " + oBoard:Product + CRLF
      ? cInfo += "" + CRLF
   NEXT
#ENDIF

RETURN cInfo

*+--------------------------------------------------------------------
*+
*+    Function BIOSInfo()
*+
*+    Called from ( runw32.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION BIOSInfo()

LOCAL oWmi, oBios
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine
LOCAL cInfo := REPLICATE( "-", 80 ) + CRLF

   oWmi := WmiService()

#IFDEF __XPP__
   AADD( aProp, "Manufacturer   " )
   AADD( aProp, "Name           " )
   AADD( aProp, "Date           " )
   AADD( aProp, "Version        " )
   AADD( aProp, "BIOS Version   " )

   colItems := oWMI:ExecQuery( "select * from Win32_BIOS",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   oService:getProperty( "Manufacturer" ), ;
                   oService:getProperty( "Name" ), ;
                   oService:getProperty( "ReleaseDate" ), ;
                   oService:getProperty( "Version" ), ;
                   oService:getProperty( "SMBIOSBIOSVersion" ) } ) }

   ComEvalCollection( colItems, bCollBlock )

   jMax := LEN( aItem )
   iMax := LEN( aItem[ 1 ] )

   FOR j := 1 TO jMax
      FOR i := 1 TO iMax - 1
         IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
         ELSE
            ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
         ENDIF
         cInfo += cLine
      NEXT
   NEXT

#ELSE
   ? cInfo += "BIOSInfo        " + CRLF
   FOR EACH oBios IN oWmi:ExecQuery( "SELECT * FROM Win32_BIOS" )
      ? cInfo += "Manufacturer    : " + oBios:Manufacturer + CRLF
      ? cInfo += "Name            : " + oBios:Name + CRLF
      ? cInfo += "Date            : " + LEFT( oBios:ReleaseDate, 8 ) + CRLF
      ? cInfo += "Version         : " + oBios:Version + CRLF
      ? cInfo += "BIOS Version    : " + oBios:SMBIOSBIOSVersion + CRLF
      ? cInfo += "" + CRLF
   NEXT
#ENDIF

RETURN cInfo

*+--------------------------------------------------------------------
*+
*+    Function PhysicalMemoryInfo()
*+
*+    Called from ( runw32.prg )   1 - procedure main()
*+
*+--------------------------------------------------------------------
*+
FUNCTION PhysicalMemoryInfo()

LOCAL oWmi, oMemory
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine
LOCAL cInfo := REPLICATE( "-", 80 ) + CRLF

   oWmi := WmiService()

#IFDEF __XPP__
   AADD( aProp, "BankLabel      " )
   AADD( aProp, "Capacity       " )
   AADD( aProp, "ClockSpeed     " )
   AADD( aProp, "Voltage        " )
   AADD( aProp, "Device         " )
   AADD( aProp, "FormFactor     " )
   AADD( aProp, "Manufacturer   " )
   AADD( aProp, "PartNumber     " )
   AADD( aProp, "MemoryType     " )
   AADD( aProp, "Speed          " )

   colItems := oWMI:ExecQuery( "select * from Win32_PhysicalMemory",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   oService:getProperty( "BankLabel" ), ;
                   oService:getProperty( "Capacity" ), ;
                   oService:getProperty( "ConfiguredClockSpeed" ), ;
                   oService:getProperty( "ConfiguredVoltage" ), ;
                   oService:getProperty( "DeviceLocator" ), ;
                   GetFormFaktorText( oService:getProperty( "FormFactor" ) ), ;
                   oService:getProperty( "Manufacturer" ), ;
                   oService:getProperty( "PartNumber" ), ;
                   GetRAMtype( oService:getProperty( "SMBIOSMemoryType" ) ), ;
                   oService:getProperty( "Speed" ) } ) }

   ComEvalCollection( colItems, bCollBlock )

   IF LEN( aItem ) > 0

      jMax := LEN( aItem )
      iMax := LEN( aItem[ 1 ] )

      FOR j := 1 TO jMax
         FOR i := 1 TO iMax - 1
            IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
               ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
            ELSE
               ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
            ENDIF
            cInfo += cLine
         NEXT
         cInfo += CRLF
      NEXT
   ENDIF
#ELSE
   ? cInfo += "MemoryInfo      " + CRLF
   FOR EACH oMemory IN oWmi:ExecQuery( "SELECT * FROM Win32_PhysicalMemory" )
      ? cInfo += "BankLabel       : " + oMemory:BankLabel + CRLF
      ? cInfo += "Capacity        : " + oMemory:Capacity + CRLF
      ? cInfo += "ClockSpeed      : " + TRIM_NUMBER( oMemory:ConfiguredClockSpeed ) + CRLF
      ? cInfo += "Voltage         : " + TRIM_NUMBER( oMemory:ConfiguredVoltage ) + CRLF
      ? cInfo += "Device          : " + oMemory:DeviceLocator + CRLF
      ? cInfo += "FormFactor      : " + GetFormFaktorText( oMemory:FormFactor ) + CRLF
      ? cInfo += "Manufacturer    : " + oMemory:Manufacturer + CRLF
      ? cInfo += "PartNumber      : " + oMemory:PartNumber + CRLF
      ? cInfo += "MemoryType      : " + GetRAMtype( oMemory:SMBIOSMemoryType ) + CRLF
      ? cInfo += "Speed           : " + TRIM_NUMBER( oMemory:Speed ) + CRLF
      ? cInfo += "" + CRLF
   NEXT
#ENDIF

RETURN cInfo

*+--------------------------------------------------------------------
*+
*+    Function OS_Info()
*+
*+    Called from ( runw32.prg )   2 - function hmg_info()
*+
*+--------------------------------------------------------------------
*+
FUNCTION OS_Info()

LOCAL oWmi, oOs
LOCAL aitem := {}, aProp := {}, bCollBlock, j, jMax, i, iMax, colItems, cLine := ""
LOCAL cInfo := ""

   oWmi := WmiService()

#IFDEF __XPP__
   AADD( aProp, "Name          " )
   AADD( aProp, "Version       " )

   colItems := oWMI:ExecQuery( "select * from Win32_OperatingSystem",, 48 )

   bCollBlock := { | oService, n | AADD( aItem, { n, ;
                   oService:getProperty( "Caption" ), ;
                   oService:getProperty( "Version" ) } ) }

   ComEvalCollection( colItems, bCollBlock )

   IF LEN( aItem ) > 0

      jMax := LEN( aItem )
      iMax := LEN( aItem[ 1 ] )

      FOR j := 1 TO jMax
         FOR i := 1 TO iMax - 1
            IF VALTYPE( aItem[ j, i + 1 ] ) = "N"
               ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + TRIM_NUMBER( aItem[ j, i + 1 ] ) + CRLF
            ELSE
               ? cLine := SUBSTR( aProp[ i ] + SPACE( 30 ), 1, 30 ) + ":" + aItem[ j, i + 1 ] + CRLF
            ENDIF
            cInfo += cLine
         NEXT
      NEXT
   ENDIF

#ELSE

   FOR EACH oOs IN oWmi:ExecQuery( "SELECT * FROM Win32_OperatingSystem" )
      ? cLine := "Name: "
      ?? cLine += oOs:Caption
      ?? cLine += "Version: "
      ?? cLine += oOs:Version
      ?? cLine += CRLF

      cInfo := oOs:Caption + " " + oOs:Version
   NEXT
#ENDIF

RETURN TRIM( cInfo )

*+--------------------------------------------------------------------
*+
*+    Static Function WMIService()
*+
*+    Called from ( runw32.prg )   2 - function hmg_info()
*+                                   1 - function processorinfo()
*+                                   1 - function baseboardinfo()
*+                                   1 - function biosinfo()
*+                                   1 - function physicalmemoryinfo()
*+                                   1 - function os_info()
*+
*+--------------------------------------------------------------------
*+
STATIC FUNCTION WMIService()

STATIC oWMI
LOCAL oLocator

   IF oWMI == NIL
      oLocator := CreateObject( "wbemScripting.SwbemLocator" )
      oWMI := oLocator:ConnectServer()
   ENDIF

RETURN oWMI

*+--------------------------------------------------------------------
*+
*+    Function TRIM_NUMBER()
*+
*+    Called from ( runw32.prg )   1 - function hmg_info()
*+                                   6 - function processorinfo()
*+                                   1 - function baseboardinfo()
*+                                   1 - function biosinfo()
*+                                   4 - function physicalmemoryinfo()
*+                                   1 - function os_info()
*+                                   1 - function getformfaktortext()
*+                                   1 - function getramtype()
*+
*+--------------------------------------------------------------------
*+
FUNCTION TRIM_NUMBER( nIn )

LOCAL cIn
   IF VALTYPE( nIn ) = "N"
      cIn := LTRIM( STR( nIn ) )
   ELSE
      cIn := LTRIM( nIn )
   ENDIF
RETURN ( cIn )

*+--------------------------------------------------------------------
*+
*+    Function GetFormFaktorText()
*+
*+    Called from ( runw32.prg )   2 - function physicalmemoryinfo()
*+
*+--------------------------------------------------------------------
*+
FUNCTION GetFormFaktorText( nIn )

LOCAL aFT   := {}
LOCAL nPosi, cText

   AADD( aFT, { 00, "Unknown" } )
   AADD( aFT, { 01, "Other" } )
   AADD( aFT, { 02, "SiP" } )
   AADD( aFT, { 03, "DIP" } )
   AADD( aFT, { 04, "ZIP" } )
   AADD( aFT, { 05, "SOJ" } )
   AADD( aFT, { 06, "Proprietary" } )
   AADD( aFT, { 07, "SIMM" } )
   AADD( aFT, { 08, "DIMM" } )
   AADD( aFT, { 09, "TSOPO" } )
   AADD( aFT, { 10, "PGA" } )
   AADD( aFT, { 11, "RIM" } )
   AADD( aFT, { 12, "SODIMM" } )
   AADD( aFT, { 13, "SRIMM" } )
   AADD( aFT, { 14, "SMD" } )
   AADD( aFT, { 15, "SSMP" } )
   AADD( aFT, { 16, "QFP" } )
   AADD( aFT, { 17, "TQFP" } )
   AADD( aFT, { 18, "SOIC" } )
   AADD( aFT, { 19, "LCC" } )
   AADD( aFT, { 20, "PLCC" } )
   AADD( aFT, { 21, "FPGA" } )
   AADD( aFT, { 22, "LGA" } )

   IF VALTYPE( nIn ) = "C"
      nIn := VAL( nIn )
   ENDIF

   nPosi := ASCAN( aFT, { | e | e[ 1 ] = nIn } )
   IF nPosi > 0
      cText := aFT[ nPosi ] [ 2 ]
   ELSE
      cText := TRIM_NUMBER( nIn )
   ENDIF
RETURN cText

*+--------------------------------------------------------------------
*+
*+    Function GetRAMtype()
*+
*+    Called from ( runw32.prg )   2 - function physicalmemoryinfo()
*+
*+--------------------------------------------------------------------
*+
FUNCTION GetRAMtype( nIn )

LOCAL aFT   := {}
LOCAL nPosi, cText

   AADD( aFT, { 00, "Unknown" } )
   AADD( aFT, { 01, "Other" } )
   AADD( aFT, { 02, "DRAM" } )
   AADD( aFT, { 03, "Synchronous DRAM" } )
   AADD( aFT, { 04, "Cache DRAM" } )
   AADD( aFT, { 05, "EDO" } )
   AADD( aFT, { 06, "EDRAM" } )
   AADD( aFT, { 07, "VRAM" } )
   AADD( aFT, { 08, "SRAM" } )
   AADD( aFT, { 09, "ROM" } )
   AADD( aFT, { 10, "ROM" } )
   AADD( aFT, { 11, "FLASH" } )
   AADD( aFT, { 12, "EEPROM" } )
   AADD( aFT, { 13, "FEPROM" } )
   AADD( aFT, { 14, "EPROM" } )
   AADD( aFT, { 15, "CDRAM" } )
   AADD( aFT, { 16, "3DRAM" } )
   AADD( aFT, { 17, "SDRAM" } )
   AADD( aFT, { 18, "SGRAM" } )
   AADD( aFT, { 19, "RDRAM" } )
   AADD( aFT, { 20, "DDR" } )
   AADD( aFT, { 21, "DDR2" } )
   AADD( aFT, { 22, "DDR2 FB-DIMM" } )

   AADD( aFT, { 24, "DDR3" } )
   AADD( aFT, { 25, "FBD2" } )
   AADD( aFT, { 26, "DDR4" } )

   IF VALTYPE( nIn ) = "C"
      nIn := VAL( nIn )
   ENDIF

   nPosi := ASCAN( aFT, { | e | e[ 1 ] = nIn } )
   IF nPosi > 0
      cText := aFT[ nPosi ] [ 2 ]
   ELSE
      cText := TRIM_NUMBER( nIn )
   ENDIF
RETURN cText

//
//
//

*+ EOF: RUNW32.PRG

